/*
 * Copyright (c) 2007 Uwe Schmidt
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * 
 * Created on 09.03.2005
 */

package controller;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.util.Properties;

public class SettingsHandler {

	private static final String header = "INI-File of the RotorDisplay Controller Application";
	private String filename;

	public SettingsHandler(String filename) {
		this.filename = filename;
	}

	// return the settings from the Ini-File (to the model)
	public Properties getSettings(Properties def) {

		Properties settings = null;

		// try to open the file and read the information
		try {
			settings = new Properties();
			settings.load(new FileInputStream(filename));

			// set settings to the default settings (passed by the model)
			// because the Ini-File wasn't found
		} catch (FileNotFoundException e) {
			settings = def;

			// catch other exceptions
		} catch (Exception e) {
			System.err.println(e);
		}

		return settings;
	}

	public void writeProperties(Properties p) {
		// try to save the Property-Object to the Ini-File
		try {
			FileOutputStream out = new FileOutputStream(filename);
			p.store(out, header);
		} catch (Exception e) {
			System.err.println(e);
		}
	}

}
