/*
 * Copyright (c) 2007 Uwe Schmidt
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * 
 * Created on 08.03.2005
 */

package controller.gui;

import java.awt.event.ActionListener;
import java.util.Observable;
import java.util.Observer;

import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;

import controller.Model;

@SuppressWarnings("serial")
public class GuiMenuBar extends JMenuBar implements Observer {

	private Model model;
	private JMenuItem newItem, openItem, saveItem;

	public GuiMenuBar(Model model, ActionListener listener) {

		this.model = model;
		model.addObserver(this);

		// Create File Menu
		JMenu menu = new JMenu("File");

		newItem = new JMenuItem("New");
		newItem.addActionListener(listener);
		menu.add(newItem);

		openItem = new JMenuItem("Open");
		openItem.addActionListener(listener);
		menu.add(openItem);

		saveItem = new JMenuItem("Save");
		saveItem.addActionListener(listener);
		menu.add(saveItem);

		JMenuItem item = new JMenuItem("Exit");
		item.addActionListener(listener);
		menu.add(item);

		this.add(menu);
		// End of File Menu

		// Create Settings Menu
		menu = new JMenu("Settings");

		item = new JMenuItem("COM-Port");
		item.addActionListener(listener);
		menu.add(item);

		item = new JMenuItem("Window");
		item.addActionListener(listener);
		menu.add(item);

		item = new JMenuItem("L&F");
		item.addActionListener(listener);
		menu.add(item);

		item = new JMenuItem("Close Port");
		item.addActionListener(listener);
		menu.add(item);

		this.add(menu);
		// End of Settings Menu

		// Create About Item
		menu = new JMenu("About");

		item = new JMenuItem("RotorDisplay");
		item.setActionCommand("About");
		item.addActionListener(listener);
		menu.add(item);

		this.add(menu);
		// End of About Item
	}

	public void update(Observable observable, Object msg) {
		if (msg == Model.PROPERTIES_CHANGE) {
			int tabindex = Integer.parseInt(model.getProperty("TabIndex"));
			if (tabindex == Model.TAB_INDEX_SCRIPT) {
				saveItem.setEnabled(true);
				newItem.setEnabled(true);
			} else {
				saveItem.setEnabled(false);
				newItem.setEnabled(false);
			}
			if (tabindex == Model.TAB_INDEX_TEXT) {
				openItem.setEnabled(false);
			} else {
				openItem.setEnabled(true);
			}
		}
	}
}
