/*
 * Copyright (c) 2007 Uwe Schmidt
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * 
 * Created on 15.03.2005
 */

package controller.gui;

import java.awt.event.ActionListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.util.Observable;
import java.util.Observer;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JToolBar;
import javax.swing.event.AncestorEvent;
import javax.swing.event.AncestorListener;

import controller.InputController;
import controller.Model;
import controller.SerialConnection;

@SuppressWarnings("serial")
public class GuiToolBar extends JToolBar implements Observer {

	private static final String newImage = "icons/new_document24";
	private static final String openImage = "icons/open_document24";
	private static final String saveImage = "icons/save24";
	private static final String exitImage = "icons/stop24";
	private static final String settingsImage = "icons/properties_doc24";
	private static final String viewImage = "icons/favorites24";
	private static final String windowImage = "icons/views24";
	private static final String aboutImage = "icons/mail24";
	private static final String closeImage = "icons/delete_x24";
	private static final String type = ".gif";
	private static final String disabled = "_d";
	private static final String hot = "_h";
	private ActionListener ic;
	private SerialConnection connection;
	private Model model;
	private JButton cp, newButton, openButton, saveButton;
	private StatusBar sb;

	public GuiToolBar(final Model model, InputController ic) {
		this.ic = ic;
		this.model = model;
		this.connection = model.getConnection();

		connection.addObserver(this);
		model.addObserver(this);

		add(genButton(exitImage, "Exit"));
		add(newButton = genButton(newImage, "New"));
		add(openButton = genButton(openImage, "Open"));
		add(saveButton = genButton(saveImage, "Save"));
		add(genButton(settingsImage, "COM-Port"));
		add(genButton(viewImage, "L&F"));
		add(genButton(windowImage, "Window"));
		add(genButton(aboutImage, "About"));

		cp = genButton(closeImage, "Close Port");
		cp.setEnabled(false);
		add(cp);

		addAncestorListener(new AncestorListener() {
			public void ancestorAdded(AncestorEvent e) {
				if (e.getAncestor() instanceof JToolBar) {
					JToolBar tb = (JToolBar) e.getAncestor();
					model.setProperty("ToolBarOrientation", tb.getOrientation() + "");
				}
			}

			public void ancestorRemoved(AncestorEvent e) {
			}

			public void ancestorMoved(AncestorEvent e) {
			}
		});
	}

	private JButton genButton(String image, String ac) {

		final ImageIcon image_n = new ImageIcon(getClass().getResource(image + type));
		final ImageIcon image_d = new ImageIcon(getClass().getResource(image + disabled + type));
		final ImageIcon image_h = new ImageIcon(getClass().getResource(image + hot + type));

		final JButton button = new JButton();
		button.setIcon(image_n);
		button.setDisabledIcon(image_d);
		button.setToolTipText(ac);
		button.setActionCommand(ac);
		button.addActionListener(ic);
		button.addMouseListener(new MouseAdapter() {
			public void mouseEntered(MouseEvent arg0) {
				button.setIcon(image_h);
				sb.setToolTip(button.getToolTipText());
			}

			public void mouseExited(MouseEvent arg0) {
				button.setIcon(image_n);
				sb.setToolTip("");
			}
		});
		return button;
	}

	public void update(Observable observable, Object msg) {

		if (observable == connection) {
			if (msg == SerialConnection.ONLINE) {
				cp.setEnabled(true);
				cp.repaint();
			}
			if (msg == SerialConnection.OFFLINE) {
				cp.setEnabled(false);
				cp.repaint();
			}
			return;
		}

		if (observable == model) {
			if (msg == Model.PROPERTIES_CHANGE) {
				int tabindex = Integer.parseInt(model.getProperty("TabIndex"));
				if (tabindex == Model.TAB_INDEX_SCRIPT) {
					saveButton.setEnabled(true);
					newButton.setEnabled(true);
				} else {
					saveButton.setEnabled(false);
					newButton.setEnabled(false);
				}
				if (tabindex == Model.TAB_INDEX_TEXT) {
					openButton.setEnabled(false);
				} else {
					openButton.setEnabled(true);
				}
			}
		}
	}

	public void setStatusbar(StatusBar sb) {
		this.sb = sb;
	}

}
