/*
 * Copyright (c) 2007 Uwe Schmidt
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * 
 * Created on 08.06.2005
 */
package controller.gui;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;

import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextPane;

import controller.InputController;
import controller.Model;

@SuppressWarnings("serial")
public class ScriptPanel extends JPanel {

	private Model model;
	private InputController ic;
	private JTextPane text;
	private JButton playButton;
	private JPanel buttonPane;
	private boolean running = false;
	private File f;

	public ScriptPanel(Model model, InputController ic) {
		this.model = model;
		this.ic = ic;

		setLayout(new BorderLayout());

		text = new JTextPane();
		text.setFont(new Font("Monospaced", Font.PLAIN, 14));
		JScrollPane scrollpane = new JScrollPane(text);
		add(scrollpane, BorderLayout.CENTER);

		// pass aligment, hgap, vgap
		buttonPane = new JPanel();
		buttonPane.setLayout(new FlowLayout(FlowLayout.CENTER, 1, 0));
		buttonPane.add(playButton = createPlayPauseButton("Play"));
		buttonPane.add(createStopButton("Stop"));
		// buttonPane.add(pauseButton = createButton("Pause"));
		add(buttonPane, BorderLayout.SOUTH);

		// sample script
		text.setText(
				"// Sample Script\n" +
				"loop on\n"+
				"send text \"R\"		wait 1 sec engine 1\n" +
				"send text \" o\"		wait 1 sec engine 2\n" +
				"send text \"  t\"		wait 1 sec engine 3\n" +
				"send text \"   o\"		wait 1 sec engine 4\n" +
				"send text \"    r\"		wait 1 sec engine 5\n" +
				"send text \"     D\"	wait 1 sec engine 6\n" +
				"send text \"      i\"	wait 1 sec engine 5\n" +
				"send text \"       s\"	wait 1 sec engine 4\n" +
				"send text \"        p\"	wait 1 sec engine 3\n" +
				"send text \"         l\"	wait 1 sec engine 2\n" +
				"send text \"          a\"	wait 1 sec engine 1\n" +
				"send text \"           y\"	wait 500 msec\n" +
				"send text \"\"		wait 500 msec\n" +
				"send text \"RotorDisplay\"	wait 1 sec\n" +
				"engine 0\n" +
				"wait 2 sec\n"
		);
	}

	private JButton createStopButton(String label) {
		JButton button = new JButton(label);
		button.addActionListener(ic);
		return button;
	}

	private JButton createPlayPauseButton(String label) {
		playButton = new JButton(label);
		playButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				running = !running;
				playButton.setText(running ? "Pause" : "Play");
				playButton.setActionCommand(playButton.getText());
				// start Action
				if (running) {
					model.playScript();
					// suspend Action
				} else {
					model.pauseScript();
				}
			}
		});
		return playButton;
	}

	public String getText() {
		return text.getText();
	}

	public void clearFileAndText() {
		text.setText("");
		f = null;
	}

	public void setRunning(boolean running) {
		this.running = running;
		playButton.setText(running ? "Pause" : "Play");
		playButton.setActionCommand(playButton.getText());
	}

	public void setFile(String filepath) {
		f = new File(filepath);
		try {
			model.log("Opening Script \"" + f.getAbsolutePath() + "\".");
			BufferedReader bufreader = new BufferedReader(new FileReader(f));
			StringBuffer sbuf = new StringBuffer();
			while (bufreader.ready())
				sbuf.append(bufreader.readLine() + "\n");
			bufreader.close();
			text.setText(sbuf.toString());
		} catch (FileNotFoundException e) {
			model.log("Script \"" + f.getAbsolutePath() + "\" not found.");
		} catch (IOException e) {
			model.log(e + "");
		}
	}

	public void saveFile(String filepath) {
		f = new File(filepath);
		saveFile();
	}

	public void saveFile() {
		if (f == null) {
			model.log("No Script opened.");
			return;
		}
		try {
			model.log("Saving Script to \"" + f.getAbsolutePath() + "\".");
			BufferedWriter bufwriter = new BufferedWriter(new FileWriter(f));
			bufwriter.write(text.getText());
			bufwriter.close();
		} catch (IOException e) {
			model.log(e + "");
		}
	}

	public boolean fileOpened() {
		return (f != null);
	}
}